@@ -1106,12 +1106,12 @@ void iniMeshData( char *datin, char *format )
   else if(compare(format,"isaac2d",7)==7)
   { 
     printf (" Try to read 2D-isaac results\n\n");
-    if ( (  readIsaac( datin, anz, &node, &elem, &lcase, &nBlock, 9, pref, tref, R_GAS)) == -1) { exit(-1);}
+    if ( (  readIsaac( datin, anz, &node, &elem, &lcase, &nBlock, 9)) == -1) { exit(-1);}
   }
   else if(compare(format,"isaac3d",7)==7)
   { 
     printf (" Try to read 3D-isaac results\n\n");
-    if ( (  readIsaac( datin, anz, &node, &elem, &lcase, &nBlock, 1, pref, tref, R_GAS)) == -1) { exit(-1);}
+    if ( (  readIsaac( datin, anz, &node, &elem, &lcase, &nBlock, 1)) == -1) { exit(-1);}
   }
   else if(compare(format,"duns2dl",7)==7)
   { 
@@ -1138,6 +1138,11 @@ void iniMeshData( char *datin, char *format )
     printf (" Try to read foam results\n\n");
     if ( (  readFoam( datin, anz, &set, &node, &elem, &lcase)) == -1) { exit(-1);}
   }
+  else if(compare(format,"vtk",3)==3)
+  { 
+    printf (" Try to read vtk file\n\n");
+    if ( (  readVtk( datin, anz, &node, &elem, &lcase)) == -1) { exit(-1);}
+  }
   else if(compare(format,"nas",2)==2)
   { 
     printf (" Try to read nastran f06 file\n\n");
@@ -1179,6 +1184,7 @@ void iniMeshData( char *datin, char *format )
   /* initialize the normal vector on each node */
   for (i=0; i<anz->n; i++) for(j=0; j<3; j++) node[node[i].nr].nv[j]=0.;
   iniElements(anz, elem, 0);
+  //printf("scal %f %f %f %f\n",scale->w,scale->x,scale->y,scale->z);
   if(anz->n>0)
   {
     if ( (set[setall].node = (int *)realloc((int *)set[setall].node, (anz->n+1) * sizeof(int))) == NULL )
@@ -1188,6 +1194,7 @@ void iniMeshData( char *datin, char *format )
     {
       set[setall].node[i]= node[i].nr;
       set[setall].anz_n++;
+      //printf(" node:%d %f %f %f\n",node[i].nr,node[node[i].nr].nx,node[node[i].nr].ny,node[node[i].nr].nz);
     }
     qsort( set[setall].node, set[setall].anz_n, sizeof(int), (void *)compareInt );
   }
@@ -1412,8 +1419,8 @@ void iniElements(Summen *anz, Elements *elem, int ini_e_enqire)
     qsort( set[setall].elem, set[setall].anz_e, sizeof(int), (void *)compareInt );
   }
 
-  /* midside nodes must be generated afer element correctrion */
-  elemChecker( set[setall].anz_e, set[setall].elem, node, e_enqire);
+  /* midside nodes must be generated after element correction */
+  //elemChecker( set[setall].anz_e, set[setall].elem, node, e_enqire);
   adjustDrawNodes(1);
 
   anz->nnext=anz->nmax+1;
